@@ -14,11 +14,11 @@ class YabaiClient:
         yabai_sockets = list(pathlib.Path("/tmp").glob("yabai_*.socket"))
         self._yabai_socket = str(yabai_sockets[0])
 
-    def send_message(self, message):
+    def send_message(self, *message):
         tries = 5
         for _ in range(tries):
             try:
-                result = self._send_message(message)
+                result = self._send_message(*message)
                 break
             except json.JSONDecodeError as err:
                 continue
@@ -26,8 +26,8 @@ class YabaiClient:
             raise RuntimeError(f"Failed to send message after {tries} attempts.")
         return result
 
-    def _send_message(self, message):
-        cleaned_message = message.replace(" ", "\0") + "\0\0"
+    def _send_message(self, *message):
+        cleaned_message = "\0".join(message) + "\0\0"
 
         with socket.socket(socket.AF_UNIX, socket.SOCK_STREAM) as sock:
             sock.connect(self._yabai_socket)
